ReadDir

Struct ReadDir 

pub struct ReadDir(/* private fields */);
Reads the entries in a directory.

This struct is returned from the super::read_dir function of this module and will yield instances of DirEntry. Through a DirEntry information like the entry’s path and possibly other metadata can be learned.

Implementations

Source

impl ReadDir

pub async fn next_entry(&mut self) -> Result<Option<DirEntry>>

Returns the next entry in the directory stream.