Empty

Struct Empty 

pub struct Empty;
Empty ignores any data written via Write, and will always be empty (returning zero bytes) when read via Read.

This struct is generally created by calling empty. Please see the documentation of empty for more details.