Repeat

Struct Repeat 

pub struct Repeat { /* private fields */ }
A reader which yields one byte over and over and over and over and over and…

This struct is generally created by calling repeat. Please see the documentation of repeat for more details.