TcpListener

Struct TcpListener 

pub struct TcpListener(/* private fields */);
A TCP socket server, listening for connections.

You can accept a new connection by using the TcpListener::accept method.

A TcpListener is created by calling TcpListener::bind.

Implementations

Source

impl TcpListener

pub async fn bind(addr: SocketAddr) -> Result<Self>

Creates a new TcpListener bound to the specified address.

The returned listener is ready for accepting connections.

pub async fn accept(&self) -> Result<(TcpStream, SocketAddr)>

Accepts a new incoming connection.

This method will block until a new connection is established.

pub fn local_addr(&self) -> Result<SocketAddr>

Returns the local address of this listener.

pub fn set_ttl(&self, ttl: u32) -> Result<()>

Sets the value for the IP_TTL option on this socket.

pub fn ttl(&self) -> Result<u32>

Gets the value for the IP_TTL option on this socket.