TcpStream

Struct TcpStream 

pub struct TcpStream(/* private fields */);
A TCP stream between a local and a remote socket.

A TCP Stream can either be created by connecting to an endpoint, via the TcpStream::connect method, or by super::TcpListener::accepting a connection from a super::TcpListener.

Reading and writing to a TcpStream is usually done by using the crate::io::Read and crate::io::Write traits.

Implementations

Source

impl TcpStream

pub async fn connect(addr: SocketAddr) -> Result<TcpStream>

Opens a TCP connection to a remote host at the specified address.

pub fn local_addr(&self) -> Result<SocketAddr>

Returns the local address that this stream is bound to.

pub fn take_error(&self) -> Result<Option<Error>>

Returns the value of the SO_ERROR option.

pub fn peer_addr(&self) -> Result<SocketAddr>

Returns the remote address that this stream is connected to.

pub fn nodelay(&self) -> Result<bool>

Gets the value of the TCP_NODELAY option on this socket.

pub fn set_nodelay(&self, nodelay: bool) -> Result<()>

Sets the value of the TCP_NODELAY option on this socket.

pub async fn peek(&self, buf: &mut [u8]) -> Result<usize>

Receives data on the socket from the remote address to which it is connected, without removing that data from the queue. On success, returns the number of bytes read.

pub fn ttl(&self) -> Result<u32>

Gets the value of the IP_TTL option on this socket.

pub fn set_ttl(&self, ttl: u32) -> Result<()>

Sets the value of the IP_TTL option on this socket.