pub struct Barrier(/* private fields */);Expand description
A barrier enables multiple threads to synchronize the beginning of some computation.
Implementations
Sourceimpl Barrier
impl Barrier
Sourcepub fn new(n: usize) -> Self
pub fn new(n: usize) -> Self
Creates a new barrier that can block a given number of threads.
A barrier will block n-1 threads which call Self::wait and then wake up all threads at once when the nth thread calls Self::wait.
Sourcepub async fn wait(&self) -> BarrierWaitResult
pub async fn wait(&self) -> BarrierWaitResult
Blocks the current thread until all threads have rendezvoused here.
Barriers are re-usable after all threads have rendezvoused once, and can be used continuously.