pub struct Instant(/* private fields */);Expand description
A measurement of a monotonically nondecreasing clock. Opaque and useful only with std::time::Duration.
Implementations
Sourceimpl Instant
impl Instant
Sourcepub fn elapsed(&self) -> Duration
pub fn elapsed(&self) -> Duration
Returns the amount of time elapsed since this instant was created, or zero duration if this instant is in the future.
Sourcepub fn checked_add(&self, duration: Duration) -> Option<Self>
pub fn checked_add(&self, duration: Duration) -> Option<Self>
Returns Some(T) where t is the time self + durationift can be represented as [Instant], otherwise None`.
Sourcepub fn checked_sub(&self, duration: Duration) -> Option<Self>
pub fn checked_sub(&self, duration: Duration) -> Option<Self>
Returns Some(T) where t is the time self - durationift can be represented as [Instant], otherwise None`.
pub fn duration_since(&self, earlier: Instant) -> Duration
Sourcepub fn checked_duration_since(&self, earlier: Instant) -> Option<Duration>
pub fn checked_duration_since(&self, earlier: Instant) -> Option<Duration>
Returns the duration since earlier if earlier is before self, otherwise returns None.
Sourcepub fn saturating_duration_since(&self, earlier: Instant) -> Duration
pub fn saturating_duration_since(&self, earlier: Instant) -> Duration
Returns the amount of time elapsed from another instant to this one, or zero duration if that instant is later than this one.