pub struct ReadDir(/* private fields */);Expand description
Reads the entries in a directory.
This struct is returned from the super::read_dir function of this module and will yield instances of DirEntry.
Through a DirEntry information like the entry’s path and possibly other metadata can be learned.
Implementations