pub struct TcpListener(/* private fields */);Expand description
A TCP socket server, listening for connections.
You can accept a new connection by using the TcpListener::accept method.
A TcpListener is created by calling TcpListener::bind.
Implementations
Sourceimpl TcpListener
impl TcpListener
Sourcepub async fn bind(addr: SocketAddr) -> Result<Self>
pub async fn bind(addr: SocketAddr) -> Result<Self>
Creates a new TcpListener bound to the specified address.
The returned listener is ready for accepting connections.
Sourcepub async fn accept(&self) -> Result<(TcpStream, SocketAddr)>
pub async fn accept(&self) -> Result<(TcpStream, SocketAddr)>
Accepts a new incoming connection.
This method will block until a new connection is established.
Sourcepub fn local_addr(&self) -> Result<SocketAddr>
pub fn local_addr(&self) -> Result<SocketAddr>
Returns the local address of this listener.