pub struct TcpStream(/* private fields */);Expand description
A TCP stream between a local and a remote socket.
A TCP Stream can either be created by connecting to an endpoint, via the TcpStream::connect method,
or by super::TcpListener::accepting a connection from a super::TcpListener.
Reading and writing to a TcpStream is usually done by using the crate::io::Read and crate::io::Write traits.
Implementations
Sourceimpl TcpStream
impl TcpStream
Sourcepub async fn connect(addr: SocketAddr) -> Result<TcpStream>
pub async fn connect(addr: SocketAddr) -> Result<TcpStream>
Opens a TCP connection to a remote host at the specified address.
Sourcepub fn local_addr(&self) -> Result<SocketAddr>
pub fn local_addr(&self) -> Result<SocketAddr>
Returns the local address that this stream is bound to.
Sourcepub fn take_error(&self) -> Result<Option<Error>>
pub fn take_error(&self) -> Result<Option<Error>>
Returns the value of the SO_ERROR option.
Sourcepub fn peer_addr(&self) -> Result<SocketAddr>
pub fn peer_addr(&self) -> Result<SocketAddr>
Returns the remote address that this stream is connected to.
Sourcepub fn set_nodelay(&self, nodelay: bool) -> Result<()>
pub fn set_nodelay(&self, nodelay: bool) -> Result<()>
Sets the value of the TCP_NODELAY option on this socket.