MutexGuard

Struct MutexGuard 

pub struct MutexGuard<'a, T: ?Sized + 'a>(/* private fields */);
An RAII implementation of a “scoped lck” of a mutex. When this structure is dropped (falls out of scope), the lock will be unlocked.

The data protected by the mutex can be accessed through this guard via its Deref and DerefMut implementations.

This structure is created by the super::Mutex::lock and super::Mutex::try_lock methods on super::Mutex.